@@ -1,8 +1,9 @@
-from typing import Any, Callable, Dict, List, NewType, Optional, Tuple, Union
+from typing import Any, Dict, List, NewType
 import torch
 
 InputDataClass = NewType("InputDataClass", Any)
 
+
 class CollateAndPadNER(object):
     def __init__(self, pad_id):
         self.pad_id = pad_id
