@@ -8,7 +8,9 @@ def encode_examples(left_context, center_context, right_context, tokenizer, max_
     center_positions = [min(len(x), max_seq_len) for x in input_ids]
 
     for encoding in [center_encoded, right_encoded]:
-        for i in range(len(input_ids)): input_ids[i].extend(encoding['input_ids'][i])
-        for i in range(len(input_ids)): attention_mask[i].extend(encoding['attention_mask'][i])
+        for i, input_id in enumerate(input_ids):
+            input_id.extend(encoding['input_ids'][i])
+        for i in range(len(input_ids)):
+            attention_mask[i].extend(encoding['attention_mask'][i])
 
     return {'input_ids': input_ids, 'center_positions': center_positions, 'attention_mask': attention_mask}
