@@ -1,9 +1,8 @@
-import pandas as pd
 import regex
 import logging
 
 
-def normalize_date(date, id, start, end):
+def normalize_date(date, id_, start, end):
     """ Normalizes different dates encountered in the clinical notes.
     Current accepted formats:
         28 Feb 2913 04:50
@@ -21,13 +20,13 @@ def normalize_date(date, id, start, end):
         # all good
         date = date.strip()
     else:
-        logging.warning("Unsuported date format: {} for id: {} with start: {}, end: {}".format(date, id, start, end))
+        logging.warning("Unsupported date format: %s for id: %s with start: %s, end: %s", date, id_, start, end)
         return None
 
     return date
 
 
-def split_one_note(id, text):
+def split_one_note(id_, text):
     """ Splits the text of one note by date.
 
     Return:
@@ -53,15 +52,15 @@ def split_one_note(id, text):
             note_text = text[start:end]
             if 'entered on -' in note_text.lower():
                 if len(regex.findall(r'entered on -', note_text)) > 1:
-                    logging.warning("Possible problems for span with start: {} and end: {} for note with id: {}".format(start, end, id))
-                split_note.append({'start': start, 'end': end, 'text': note_text, 'date': normalize_date(previous_date, id, start, end)})
+                    logging.warning("Possible problems for span with start: %s and end: %s for note with id: %s", start, end, id_)
+                split_note.append({'start': start, 'end': end, 'text': note_text, 'date': normalize_date(previous_date, id_, start, end)})
                 start = end
                 previous_date = date.captures()[0]
     # Add the last note
     if previous_date is not None and 'entered on -' in text[start:].lower():
-        split_note.append({'start': start, 'end': len(text), 'text': text[start:], 'date': normalize_date(previous_date, id, start, len(text))})
+        split_note.append({'start': start, 'end': len(text), 'text': text[start:], 'date': normalize_date(previous_date, id_, start, len(text))})
     else:
-        logging.warning("No date/entered-on detected for id: {} wth start: {}, end: {} and text:\n{}...".format(id, start, end, text[0:300]))
+        logging.warning("No date/entered-on detected for id: %s wth start: %s, end: %s and text:\n%s...", id_, start, end, text[0:300])
 
     return split_note
 
@@ -74,6 +73,6 @@ def split_clinical_notes(clinical_notes):
             Dictionary in the form {<clinical_note_id>: <text>, ...}
     """
     split_notes = {}
-    for id, text in clinical_notes.items():
-        split_notes[id] = split_one_note(id, text)
+    for id_text, text in clinical_notes.items():
+        split_notes[id_text] = split_one_note(id_text, text)
     return split_notes
