@@ -1,5 +1,6 @@
 import re
 import spacy
+from medcat.pipeline.pipe_runner import PipeRunner
 
 
 CONTAINS_NUMBER = re.compile('[0-9]+')
@@ -13,18 +14,16 @@ class BasicSpellChecker(object):
         self.config = config
         self.data_vocab = data_vocab
 
-
     def P(self, word):
         "Probability of `word`."
-	# use inverse of rank as proxy
-	# returns 0 if the word isn't in the dictionary
+    # use inverse of rank as proxy
+    # returns 0 if the word isn't in the dictionary
         cnt = self.vocab.get(word, 0)
         if cnt != 0:
             return -1 / cnt
         else:
             return 0
 
-
     def __contains__(self, word):
         if word in self.vocab:
             return True
@@ -33,7 +32,6 @@ class BasicSpellChecker(object):
         else:
             return False
 
-
     def fix(self, word):
         "Most probable spelling correction for word."
         fix = max(self.candidates(word), key=self.P)
@@ -46,20 +44,22 @@ class BasicSpellChecker(object):
         "Generate possible spelling corrections for word."
         if self.config.general['spell_check_deep']:
             # This will check a two letter edit distance
-            return (self.known([word]) or self.known(self.edits1(word)) or self.known(self.edits2(word)) or [word])
+            return self.known([word]) or self.known(self.edits1(word)) or self.known(self.edits2(word)) or [word]
         else:
             # Will check only one letter edit distance
-            return (self.known([word]) or self.known(self.edits1(word))  or [word])
-
+            return self.known([word]) or self.known(self.edits1(word)) or [word]
 
     def known(self, words):
         "The subset of `words` that appear in the dictionary of WORDS."
         return set(w for w in words if w in self.vocab)
 
-
     def edits1(self, word):
         "All edits that are one edit away from `word`."
         letters    = 'abcdefghijklmnopqrstuvwxyz'
+
+        if self.config.general['diacritics']:
+            letters += 'àáâãäåæçèéêëìíîïðñòóôõöøùúûüýþÿ'
+
         splits     = [(word[:i], word[i:])    for i in range(len(word) + 1)]
         deletes    = [L + R[1:]               for L, R in splits if R]
         transposes = [L + R[1] + R[0] + R[2:] for L, R in splits if len(R)>1]
@@ -67,19 +67,17 @@ class BasicSpellChecker(object):
         inserts    = [L + c + R               for L, R in splits for c in letters]
         return set(deletes + transposes + replaces + inserts)
 
-
     def edits2(self, word):
         "All edits that are two edits away from `word`."
         return (e2 for e1 in self.edits1(word) for e2 in self.edits1(e1))
 
-
     def edits3(self, word):
         "All edits that are two edits away from `word`."
         # Do d3 edits
         pass
 
 
-class TokenNormalizer(object):
+class TokenNormalizer(PipeRunner):
     r''' Will normalize all tokens in a spacy document.
 
     Args:
@@ -94,6 +92,7 @@ class TokenNormalizer(object):
         self.config = config
         self.spell_checker = spell_checker
         self.nlp = spacy.load(config.general['spacy_model'], disable=config.general['spacy_disabled_components'])
+        super().__init__(self.config.general['workers'])
 
     def __call__(self, doc):
         for token in doc:
